library(testthat)
library(vcr)
test_check("rmangal")
